# Red-Dashboard
*An easy-to-use interactive web dashboard to control your Redbot.*

## Warning
This webserver is in alpha stages, and is not yet encouraged for use.  Repository owners nor any contributors are responsible for any possible data corruptions or data loss that may occur while using this program.  Proceed at your own risk.

## Installation
The Red Discord Bot - Dashboard is supported on Windows, Mac OS X and Linux distributions.  To install, please take a look at docuemtentation that be found [here](https://red-dashboard.readthedocs.io/en/latest/).

## Help
If you wish to use this program and receive support for it, you must also give feedback and report any bugs you encounter.  You can join my support server [here](https://discord.gg/vQZTdB9).

## Credits
I would like to thank the following, for all the contributions they have made that helped this become what it is today.
* Predeactor, for setting up a huge amount of the documentation.
* Cog Creators, for making such an amazing bot.
* All the people who tested the dashboard, and gave feedback.
* AppSeed, for creating a template that I use as the base for the Dashboard.
